@@ -23,7 +23,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 package Graphics::GVG;
-$Graphics::GVG::VERSION = '0.1';
+$Graphics::GVG::VERSION = '0.3';
 # ABSTRACT: Game Vector Graphics
 use strict;
 use warnings;
@@ -51,14 +51,19 @@ my $DSL = <<'END_DSL';
     :default ::= action => _do_first_arg
 
 
-    Start ::= Block+ action => _do_build_ast_obj
+    Start ::= Blocks action => _do_build_ast_obj
 
-    Block ::= Functions | EffectBlocks | ColorVariableSet | NumberVariableSet
+    Blocks ::= Block+ action => _do_blocks
+
+    Block ::= Functions
+        | EffectBlocks
+        | ColorVariableSet
+        | NumberVariableSet
         | IntegerVariableSet
 
     EffectBlocks ::= EffectBlock+ action => _do_arg_list_ref
 
-    EffectBlock ::= EffectName OpenCurly Block CloseCurly
+    EffectBlock ::= EffectName OpenCurly Blocks CloseCurly
         action => _do_effect_block
 
     EffectName ~ 'glow'
@@ -69,6 +74,7 @@ my $DSL = <<'END_DSL';
         | CircleFunc SemiColon
         | EllipseFunc SemiColon
         | RectFunc SemiColon
+        | PointFunc SemiColon
         | PolyFunc SemiColon
 
     LineFunc ::= 
@@ -91,6 +97,11 @@ my $DSL = <<'END_DSL';
             ColorValue Comma NumberValue Comma NumberValue Comma NumberValue Comma NumberValue
             CloseParen action => _do_rect_func
 
+    PointFunc ::= 
+        'point' OpenParen
+            ColorValue Comma NumberValue Comma NumberValue Comma NumberValue 
+            CloseParen action => _do_point_func
+
     PolyFunc ::= 
         'poly' OpenParen
             ColorValue Comma NumberValue Comma NumberValue Comma NumberValue Comma IntegerValue Comma NumberValue
@@ -117,6 +128,10 @@ my $DSL = <<'END_DSL';
 
     IntegerLookup ::= '&' VarName action => _do_int_lookup
 
+    # TODO
+    #Include ::= '^include<' FileName '>'
+    #    action => _do_include
+
     Number ~ Digits
         | Digits Dot Digits
         | Negative Digits
@@ -163,6 +178,11 @@ my $RECCE = Marpa::R2::Scanless::R->new({
     grammar => $GRAMMAR,
 });
 
+has 'include_paths' => (
+    is => 'ro',
+    isa => 'ArrayRef[Str]',
+    default => sub {[]},
+);
 has '_num_vars' => (
     is => 'ro',
     isa => 'HashRef[Num]',
@@ -253,6 +273,20 @@ sub _do_rect_func
     return $cmd;
 }
 
+sub _do_point_func
+{
+    # 'point' OpenParen ColorValue Comma NumberValue Comma NumberValue Comma NumberValue 
+    my ($self, undef, undef, $color, undef, $x, undef, $y, undef, $size) = @_;
+    $color = $self->_color_hex_to_int( $color );
+    my $line = Graphics::GVG::AST::Point->new({
+        x => $x,
+        y => $y,
+        size => $size,
+        color => $color,
+    });
+    return $line;
+}
+
 sub _do_poly_func
 {
     # 'poly' OpenParen ColorValue Comma NumberValue Comma NumberValue Comma NumberValue Comma IntegerValue Comma NumberValue
@@ -270,6 +304,16 @@ sub _do_poly_func
     return $cmd;
 }
 
+sub _do_blocks
+{
+    # Block+ 
+    my ($self, @blocks) = @_;
+    @blocks =
+        map { @$_ if ref $_ }
+        grep { defined } @blocks;
+    return \@blocks;
+}
+
 sub _do_effect_block
 {
     # EffectName OpenCurly Start CloseCurly
@@ -374,6 +418,44 @@ sub _do_int_lookup
     return $self->_int_vars->{$name};
 }
 
+sub _do_include
+{
+    # '^include<' IncludeFile '>'
+    my ($self, undef, $file) = @_;
+
+    my $full_path = undef;
+    foreach my $start_path (@{ $self->include_paths }) {
+        # TODO safer cross platform file concat
+        my $check_path = $start_path . '/' . $file;
+
+        if( -e $check_path ) {
+            $full_path = $check_path;
+            last;
+        }
+    }
+
+    if(! defined $full_path ) {
+        die "Could not find include file '$file' in directories: \n"
+            . join( "\n", map { "\t$_" } @{ $self->include_paths } ) . "\n";
+    }
+
+    my $input = '';
+    open( my $in, '<', $full_path ) or die "Can't open $full_path: $!\n";
+    while( my $line = <$in> ) {
+        $input .= $line;
+    }
+    close $in;
+
+    # TODO clone the current GVG, which will let variables fall through into 
+    # the include
+    my $gvg = Graphics::GVG->new({
+        include_paths => $self->include_paths,
+    });
+    my $ast = $gvg->parse( $input );
+
+    return @{ $ast->commands };
+}
+
 
 #
 # Helper functions
@@ -416,8 +498,8 @@ __END__
 
 Parses scripts that describe vectors used for gaming graphics. The script is 
 parsed into an Abstract Syntax Tree (AST), which can then be transformed into 
-different forms. For example, the OpenGL renderer generates Perl code that 
-can be compiled and called inside a larger Perl/OpenGL program.
+different forms. For example, L<Graphics::GVG::OpenGLRender> generates Perl code
+that can be compiled and called inside a larger Perl/OpenGL program.
 
 =head1 LANGUAGE
 
@@ -511,6 +593,12 @@ C<$x + $width> and C<$y + $height>.
 An ellipse of the given C<%color>, centered at C<$cx,$cy>, with respective radii
 C<$rx> and C<$ry>.
 
+=head3 point
+
+  point( %color, $x, $y, $size );
+
+A point of the given C<%color>, at C<$x,$y>, with size C<$size>.
+
 =head3 poly
 
   poly( %color, $cx, $cy, &sides, $r );
