@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package Graphics::GVG::AST::Polygon;
-$Graphics::GVG::AST::Polygon::VERSION = '0.1';
+$Graphics::GVG::AST::Polygon::VERSION = '0.3';
 use strict;
 use warnings;
 use Moose;
@@ -59,11 +59,13 @@ sub BUILDARGS
     my $radius = $args->{r};
     my $sides = $args->{sides};
     my $rotate = $args->{rotate};
+    my $cx = $args->{cx};
+    my $cy = $args->{cy};
 
     $args->{coords} = [
         map {[
-            $class->_calc_x_coord( $_, $sides, $radius, $rotate ),
-            $class->_calc_y_coord( $_, $sides, $radius, $rotate ),
+            $class->_calc_x_coord( $_, $sides, $radius, $rotate, $cx ),
+            $class->_calc_y_coord( $_, $sides, $radius, $rotate, $cy ),
         ]} (1 .. $sides)
     ];
     return $args;
@@ -72,14 +74,16 @@ sub BUILDARGS
 
 sub _calc_x_coord
 {
-    my ($class, $side, $total_sides, $radius, $rotate) = @_;
-    return $radius * cos( 2 * pi * $side / $total_sides + deg2rad($rotate) );
+    my ($class, $side, $total_sides, $radius, $rotate, $cx) = @_;
+    return $cx
+        + $radius * cos( 2 * pi * $side / $total_sides + deg2rad($rotate) );
 }
 
 sub _calc_y_coord
 {
-    my ($class, $side, $total_sides, $radius, $rotate) = @_;
-    return $radius * sin( 2 * pi * $side / $total_sides + deg2rad($rotate) );
+    my ($class, $side, $total_sides, $radius, $rotate, $cy) = @_;
+    return $cy
+        + $radius * sin( 2 * pi * $side / $total_sides + deg2rad($rotate) );
 }
 
 
